import { NextRequest, NextResponse } from "next/server";

export async function POST(req: NextRequest) {
  try {
    const { code, type, apiKey } = await req.json();
    // console.log("Received request:", { title, type, apiKey });

    if (!apiKey) {
      console.error("❌ Missing OpenAI API Key");
      return NextResponse.json({ error: "Missing OpenAI API Key" }, { status: 400 });
    }

    // 📝 Define coding languages for conversion
const prompts: Record<string, string> = {
    "Python": "Python",
    "JavaScript": "JavaScript",
    "Java": "Java",
    "C++": "C++",
    "C#": "C#",
    "Ruby": "Ruby",
    "Swift": "Swift",
    "Go": "Go",
    "PHP": "PHP",
    "TypeScript": "TypeScript",
    "Dart": "Dart",
    "Kotlin": "Kotlin",
  };
  
  const prompt = `Convert the given code to **${prompts[type]}** without modifying its logic, structure, or behavior.  
  
  **Guidelines:**  
  - Ensure precise syntax and best practices for **${prompts[type]}**.  
  - Do **not** introduce additional changes, optimizations, or explanations.  
  - Keep the formatting clean and readable.  
  - Maintain comments as they are.  
  
  **This is the Code:**  
  \`\`\`${code}\n\`\`\`
  
 `;
  
  // The code conversion logic will append the generated output here
  
    console.log("Generated prompt:", prompt);

      // 🌍 Call OpenAI API
      const response = await fetch("https://api.openai.com/v1/chat/completions", {
        method: "POST",
        headers: {
          
          "Content-Type": "application/json",
          "Authorization": `Bearer ${apiKey}`,
        },
        body: JSON.stringify({
          model: "gpt-4o-mini",
          messages: [
              { role: "user", content: prompt },  // Using the prompt here as a message from the user
            ],
            temperature: 0.7,  // Adjust temperature for creativity
          max_tokens: 1000,
        }),
      });
    if (!response.ok) {
      console.error("❌ Error calling OpenAI API:", response.status, response.statusText);
      return NextResponse.json({ error: "Failed to generate article from OpenAI" }, { status: 500 });
    }

    const data = await response.json();
    console.log("OpenAI response:", data);

    if (!data.choices || data.choices.length === 0) {
      console.error("❌ No choices in OpenAI response");
      return NextResponse.json({ error: "No content returned from OpenAI" }, { status: 500 });
    }

    return NextResponse.json({ content: data.choices[0].message.content });

  } catch (error) {
    console.error("❌ Error in OpenAI request:", error);
    return NextResponse.json({ error: "Failed to generate article" }, { status: 500 });
  }
}
